import maya.cmds as cmds

ver_number = '1.01'

'''
1.01 changelog
- added auto-apply switch
'''

# declare null shaders values
# diff_map=diff_node=diff_node_full=diff_text=diff_RGB=diff_weight=refl_map=refl_node=refl_text=refl_RGB=refl_weight=refl_gloss=bump_map=bump_2d_node=bump_node=bump_text=bump_weight=opacity_map=opacity_weight=opacity_text=opacity_node=opacity_node_full=-1


class ShaderStandard (object):
	def __init__(self):

		self.oct_warning = 0
		self.vray_warning = 0 # useless

		# file node out name
		self.fileOut = 'fileTextureName'

		# shader color channel
		self.diff = 'color'
		self.diffAmount = 'diffuse'
		# shader reflection channel
		self.refl = 'reflectedColor'
		self.reflAmount = 'reflectivity'
		self.glossAmount = 'cosinePower' # (2,100)
		# shader bump channel
		self.bump = 'normalCamera'

		# bump values
		self.bump_2d_node = 1
		self.bumpAmount = 'bumpDepth'
		self.out_bump = 'outNormal'

		# opacity
		self.opacity = 'transparency'
		self.illumination = 'incandescence'

class ShaderMR (object):
	def __init__(self):

		self.oct_warning = 0
		self.vray_warning = 0

		# file node out name
		self.fileOut = 'fileTextureName'

		# shader color channel
		self.diff = 'diffuse'
		self.diffAmount = 'diffuse_weight'
		# shader reflection channel
		self.refl = 'refl_color'
		self.reflAmount = 'reflectivity'
		self.glossAmount = 'refl_gloss'
		# shader bump channel
		self.bump = 'standard_bump'

		# bump values
		self.bump_2d_node = 1
		self.bumpAmount = 'bumpDepth'
		self.out_bump = 'outNormal'
		
		# opacity
		self.opacity = 'cutout_opacity'
		self.illumination = 'additional_color'


class ShaderVray (object):
	def __init__(self):

		self.oct_warning = 0
		self.vray_warning = 1

		# file node out name
		self.fileOut = 'fileTextureName'

		# shader color channel
		self.diff = 'color'
		self.diffAmount = 'diffuseColorAmount'
		# shader reflection channel
		self.refl = 'reflectionColor'
		self.reflAmount = 'reflectionColorAmount'
		self.glossAmount = 'reflectionGlossiness'
		# shader bump channel
		self.bump = 'bumpMap'

		# bump values
		self.bump_2d_node = 0
		self.bumpAmount = 'bumpMult'
		self.out_bump = 'outColor'

		# opacity
		self.opacity = 'transparency'
		self.illumination = 'illumColor'

class ShaderAI (object):
	def __init__(self):

		self.oct_warning = 0
		self.vray_warning = 0

		# file node out name
		self.fileOut = 'fileTextureName'

		# shader color channel
		self.diff = 'color'
		self.diffAmount = 'Kd'
		# shader reflection channel
		self.refl = 'KsColor'
		self.reflAmount = 'Ks'
		self.glossAmount = 'specularRoughness'
		# shader bump channel
		self.bump = 'normalCamera'

		# bump values
		self.bump_2d_node = 1
		self.bumpAmount = 'bumpDepth'
		self.out_bump = 'outNormal'

		# opacity
		self.opacity = 'opacity'
		self.illumination = 'emissionColor'

class ShaderOct (object):
	def __init__(self):

		self.oct_warning = 1
		self.vray_warning = 0

###################### FUNCTIONS #####################################


'''
########################################  GET SHADER  ############################################
'''
		
		
def GetShader(i,j,shaderType,diff_map,diff_node,diff_node_full,diff_text,diff_RGB,diff_weight,refl_map,refl_node,refl_text,refl_RGB,refl_weight,refl_gloss,bump_map,bump_2d_node,bump_node,bump_text,bump_weight,opacity_map,opacity_weight,opacity_text,opacity_node,opacity_node_full):

	# reset values
	diff_map=diff_node=diff_node_full=diff_text=diff_RGB=diff_weight=refl_map=refl_node=refl_text=refl_RGB=refl_weight=refl_gloss=bump_map=bump_2d_node=bump_node=bump_text=bump_weight=opacity_map=opacity_weight=opacity_text=opacity_node=opacity_node_full=-1
	

	
	if j.oct_warning == 0:
		# diffuse map / value, diffuse amount
		if cmds.listConnections('%s.%s'%(i,j.diff)):
			diff_map = 1
			diff_node = (cmds.listConnections('%s.%s'%(i,j.diff)))[0]
			try:
				diff_text = cmds.getAttr('%s.%s'%(diff_node,j.fileOut))
			except:
				print 'diff_text not found on shader %s'%i
			diff_node_full = (cmds.listConnections('%s.%s'%(i,j.diff),c=1,p=1))[1] # new line
		else:
			diff_map = 0
			diff_RGB = (cmds.getAttr('%s.%s'%(i,j.diff)))[0]

		diff_weight = cmds.getAttr('%s.%s'%(i,j.diffAmount))

		# reflection map / value, reflection amount
		if shaderType != 'lambert':
			if cmds.listConnections('%s.%s'%(i,j.refl)):
				refl_map = 1
				refl_node = (cmds.listConnections('%s.%s'%(i,j.refl)))[0]
				try:
					refl_text = cmds.getAttr('%s.%s'%(refl_node,j.fileOut))
				except:
					print 'refl_text not found on shader %s'%i
			else:
				refl_map = 0
				refl_RGB = (cmds.getAttr('%s.%s'%(i,j.refl)))[0]
	
			if cmds.objExists('%s.%s'%(i,j.reflAmount)):
				refl_weight = cmds.getAttr('%s.%s'%(i,j.reflAmount))

		# glossiness per shader
		if shaderType == 'blinn':
			refl_gloss = 1.0-(cmds.getAttr('%s.eccentricity'%i))
		if shaderType == 'lambert':
			refl_gloss = 1.0
			refl_weight = 0.0
		if shaderType == 'phong':
			refl_gloss = (cmds.getAttr('%s.cosinePower'%i))
			refl_gloss = (float(refl_gloss - 2.0)) / 98.0
		if shaderType == 'phongE':
			refl_gloss = 1.0-(cmds.getAttr('%s.roughness'%i))
		if shaderType == 'mia_material' or shaderType == 'mia_material_x' or shaderType == 'mia_material_x_passes':
			refl_gloss = (cmds.getAttr('%s.refl_gloss'%i))
		if shaderType == 'VRayMtl':
			refl_gloss = (cmds.getAttr('%s.reflectionGlossiness'%i))
		if shaderType == 'aiStandard':
			refl_gloss = 1.0-(cmds.getAttr('%s.specularRoughness'%i))


		# bump map / value
		# for all shaders
		if j.bump_2d_node == 1:

			if cmds.listConnections('%s.%s'%(i,j.bump)):
				bump_map = 1
				bump_2d_node = (cmds.listConnections('%s.%s'%(i,j.bump)))[0]
				bump_node = (cmds.listConnections('%s.bumpValue'%bump_2d_node))[0]
				bump_text = cmds.getAttr('%s.%s'%(bump_node,j.fileOut))
				bump_weight = cmds.getAttr('%s.%s'%(bump_2d_node,j.bumpAmount))


			else:
				bump_map = 0
				bump_weight = 1

		# for vray only
		if j.bump_2d_node == 0:

			if cmds.listConnections('%s.%s'%(i,j.bump)):
				bump_map = 1
				bump_node = (cmds.listConnections('%s.%s'%(i,j.bump)))[0]
				bump_text = cmds.getAttr('%s.%s'%(bump_node,j.fileOut))
				bump_weight = cmds.getAttr('%s.%s'%(i,j.bumpAmount))

			else:
				bump_map = 0
				bump_weight = 1

		# opacity / self-illumination

		if cmds.listConnections('%s.%s'%(i,j.opacity)):
			
			opacity_map = 1
			opacity_node = (cmds.listConnections('%s.%s'%(i,j.opacity)))[0]
			try:
				opacity_text = cmds.getAttr('%s.%s'%(opacity_node,j.fileOut))
			except:
				print 'opacity_text not found on shader %s'%i
			opacity_node_full = (cmds.listConnections('%s.%s'%(i,j.opacity),c=1,p=1))[1]
			opacity_weight = 1
			
		
		else:
			opacity_map = 0
			
			if shaderType == 'mia_material' or shaderType == 'mia_material_x' or shaderType == 'mia_material_x_passes':
				opacity_weight = (cmds.getAttr('%s.%s'%(i,j.opacity)))
				opacity_weight = (opacity_weight,opacity_weight,opacity_weight)

			else:
				opacity_weight = (cmds.getAttr('%s.%s'%(i,j.opacity)))[0]



	if j.oct_warning == 1:
		# OCTANE SHADER
		if shaderType == 'octaneDiffuseMaterial' or shaderType == 'octaneGlossyMaterial' or shaderType == 'octaneSpecularMaterial':
			if cmds.listConnections('%s.Diffuse'%i):
				diff_node = (cmds.listConnections('%s.Diffuse'%i))[0]
				diff_text_temp = cmds.getAttr('%s.File'%diff_node)
				diff_text_temp = [x.replace('\\','/') for x in diff_text_temp]
				diff_text = ''.join(diff_text_temp)
			else:
				diff_map = 0
				diff_weight = 1
			if cmds.listConnections('%s.Specular'%i):
				refl_node = (cmds.listConnections('%s.Specular'%i))[0]
				refl_text_temp = cmds.getAttr('%s.File'%refl_node)
				refl_text_temp = [x.replace('\\','/') for x in refl_text_temp]
				refl_text = ''.join(refl_text_temp)
			else:
				refl_map = 0
				refl_weight = 1
			if cmds.listConnections('%s.Bump'%i):
				bump_node = (cmds.listConnections('%s.Bump'%i))[0]
				bump_text_temp = cmds.getAttr('%s.File'%bump_node)
				bump_text_temp = [x.replace('\\','/') for x in bump_text_temp]
				bump_text = ''.join(bump_text_temp)
			else:
				bump_map = 0
				bump_weight = 1

			refl_gloss = 1
	
	return i,j,shaderType,diff_map,diff_node,diff_node_full,diff_text,diff_RGB,diff_weight,refl_map,refl_node,refl_text,refl_RGB,refl_weight,refl_gloss,bump_map,bump_2d_node,bump_node,bump_text,bump_weight,opacity_map,opacity_weight,opacity_text,opacity_node,opacity_node_full
			
'''
########################################  SET SHADER  ############################################
'''


def SetShader(anyshader,i,j,destinationShader,diff_map,diff_node,diff_node_full,diff_text,diff_RGB,diff_weight,refl_map,refl_node,refl_text,refl_RGB,refl_weight,refl_gloss,bump_map,bump_2d_node,bump_node,bump_text,bump_weight,opacity_map,opacity_weight,opacity_text,opacity_node,opacity_node_full):
	

	prefix = ""
	suffix = ""	
	
	prefix = cmds.textField("Prefix_name",q=1,tx=1)
	suffix = cmds.textField("Suffix_name",q=1,tx=1)
	
	apply_val = cmds.checkBox("Apply_chk", q=1, v=1)
	
		
	
	# SG_switch will determine the type of connection between the shader and the SG
	SG_switch = -1
	
	# Change destinationShader string quickfix
	if destinationShader == 'Maya Blinn':
		l = ShaderStandard()
		SG_switch = 0
		destinationShader = 'blinn'
		
	if destinationShader == 'Maya Lambert':
		l = ShaderStandard()
		SG_switch = 0
		destinationShader = 'lambert'
		
	if destinationShader == 'Maya Phong':
		l = ShaderStandard()
		SG_switch = 0
		destinationShader = 'phong'
		
	if destinationShader == 'Maya Phong E':
		l = ShaderStandard()
		SG_switch = 0
		destinationShader = 'phongE'
		
	if destinationShader == 'Mia_material':
		l = ShaderMR()
		SG_switch = 1
		destinationShader = 'mia_material'
	
	if destinationShader == 'Mia_material_x':
		l = ShaderMR()
		SG_switch = 1
		destinationShader = 'mia_material_x'
	
	if destinationShader == 'Mia_material_x_passes':
		l = ShaderMR()
		SG_switch = 1
		destinationShader = 'mia_material_x_passes'
			
	if destinationShader == 'VRayMtl':
		l = ShaderVray()
		SG_switch = 0
		destinationShader = 'VRayMtl'
		
	if destinationShader == 'AiStandard':
		l = ShaderAI()
		SG_switch = 0
		destinationShader = 'aiStandard'
		
	if destinationShader == 'Octane Diffuse material':
		l = ShaderOct()
		SG_switch = 0
		destinationShader = 'octaneDiffuseMaterial'
		
	if destinationShader == 'Octane Glossy material':
		l = ShaderOct()
		SG_switch = 0
		destinationShader = 'octaneGlossyMaterial'
		
	if destinationShader == 'Octane Specular material':
		l = ShaderOct()
		SG_switch = 0
		destinationShader = 'octaneSpecularMaterial'


	#create the shader and SG
	SG = cmds.sets(renderable=True,noSurfaceShader=True,empty=True, name='%s%sSG%s'%(prefix,i,suffix))
	shader = cmds.shadingNode(destinationShader,n='%s%s%s'%(prefix,i,suffix),asShader=True)


	if SG_switch == 1:
		cmds.connectAttr('%s.message'%shader ,'%s.miMaterialShader'%SG)
		cmds.connectAttr('%s.message'%shader ,'%s.miPhotonShader'%SG)
		cmds.connectAttr('%s.message'%shader ,'%s.miShadowShader'%SG)
	else:
		cmds.connectAttr('%s.outColor'%shader ,'%s.surfaceShader'%SG)


	# plug the queried values
	# diffuse
	if diff_map == 1:
		try:
			cmds.connectAttr(diff_node_full,'%s.%s'%(shader,l.diff))
		except:
			cmds.connectAttr('%s.%s'%(diff_node,'outColor'),'%s.%s'%(shader,l.diff))
	if diff_map == 0:
		cmds.setAttr('%s.%s'%(shader,l.diff),diff_RGB[0],diff_RGB[1],diff_RGB[2])
	
	cmds.setAttr('%s.%s'%(shader,l.diffAmount),diff_weight)

	# reflection
	if destinationShader != 'lambert':
		if refl_map == 1:
			cmds.connectAttr('%s.outColor'%refl_node, '%s.%s'%(shader,l.refl))
			cmds.setAttr('%s.%s'%(shader,l.reflAmount),refl_weight)
		if refl_map == 0:
			cmds.setAttr('%s.%s'%(shader,l.refl),refl_RGB[0],refl_RGB[1],refl_RGB[2])
			cmds.setAttr('%s.%s'%(shader,l.reflAmount),refl_weight)

	else:
		pass;

	# glossiness
	if destinationShader == 'blinn':
		refl_gloss = 1-refl_gloss
		cmds.setAttr('%s.eccentricity'%(shader),refl_gloss)
	if destinationShader == 'lambert':
		pass;
	if destinationShader == 'phong':
		refl_gloss = (refl_gloss * 98) + 2
		cmds.setAttr('%s.cosinePower'%(shader),refl_gloss)
	if destinationShader == 'phongE':
		refl_gloss = 1-refl_gloss
		cmds.setAttr('%s.roughness'%(shader),refl_gloss)
	if destinationShader == 'mia_material_x' or destinationShader == 'mia_material_x_passes':
		cmds.setAttr('%s.refl_gloss'%(shader),refl_gloss)
	if destinationShader == 'VRayMtl':
		cmds.setAttr('%s.reflectionGlossiness'%(shader),refl_gloss)
	if destinationShader == 'aiStandard':
		refl_gloss = 1-refl_gloss
		cmds.setAttr('%s.specularRoughness'%(shader),refl_gloss)

	# bump
	if bump_map == 1:

		# if coming from a vray shader
		if j.vray_warning == 1:
			
			# normal condition
			if destinationShader != 'VRayMtl':
				cmds.setAttr((bump_node+'.alphaIsLuminance'),1)
				bump_2d_node = cmds.shadingNode('bump2d',asUtility=1)
				cmds.connectAttr('%s.%s'%(bump_node,'outAlpha'), '%s.%s'%(bump_2d_node,'bumpValue'))
				cmds.connectAttr('%s.%s'%(bump_2d_node,'outNormal'), '%s.%s'%(shader,l.bump))

			# if both shaders are vray...
			else:
				'''
				# vray in get function
				bump_map = 1
				bump_node = (cmds.listConnections('%s.%s'%(i,j.bump)))[0]
				bump_text = cmds.getAttr('%s.%s'%(bump_node,j.fileOut))
				bump_weight = cmds.getAttr('%s.%s'%(i,j.bumpAmount))
				'''
				cmds.setAttr((bump_node+'.alphaIsLuminance'),1)
				bump_2d_node = shader
				cmds.connectAttr('%s.%s'%(bump_node,'outColor'), '%s.%s'%(bump_2d_node,l.bump))


		
		# if coming from other shaders	
		if j.vray_warning == 0:

			# to a new vray shader
			if destinationShader == 'VRayMtl':
				cmds.connectAttr('%s.%s'%(bump_node,'outColor'),'%s.%s'%(shader,l.bump))
				bump_2d_node = shader
			# to a normal shader
			else:
				cmds.connectAttr('%s.%s'%(bump_2d_node,'outNormal'), '%s.%s'%(shader,l.bump))

		
		cmds.setAttr('%s.%s'%(bump_2d_node,l.bumpAmount),bump_weight)

	# opacity

	if opacity_map == 1:
		#if destinationShader == 'mia_material' or destinationShader == 'mia_material_x' or destinationShader == 'mia_material_x_passes':
		try:
			try:
				cmds.connectAttr(opacity_node_full,'%s.%s'%(shader,l.opacity))
			except:
				cmds.connectAttr(opacity_node,'%s.%s'%(shader,l.opacity))
		except:
			try:
				cmds.connectAttr('%s.%s'%(opacity_node,'outAlpha'),'%s.%s'%(shader,l.opacity))
			except:
				cmds.connectAttr('%s.%s'%(opacity_node,'outColor'),'%s.%s'%(shader,l.opacity))

		else:
			print ('Maybe could not connect opacity on shader %s'%shader)

	else:
		if destinationShader == 'mia_material' or destinationShader == 'mia_material_x' or destinationShader == 'mia_material_x_passes':
			if opacity_weight[0] == opacity_weight[1] == opacity_weight[2]:
				cmds.setAttr('%s.%s'%(shader,l.opacity),opacity_weight[0])
			else:
				# same solution, workaround for MR float value vs double 3
				cmds.setAttr('%s.%s'%(shader,l.opacity),opacity_weight[0])

		else:
			cmds.setAttr('%s.%s'%(shader,l.opacity),opacity_weight[0],opacity_weight[1],opacity_weight[2])

			
		
	if bump_map == 0:
		pass;

	# ADD OPACITY AND ILLUMINATION VALUES
	# ADD OCTANE PROCEDURE + l.octane_warning condition
	
	#auto-apply
	if apply_val == True:
	    try:
	        shaders_objs = cmds.hyperShade(objects = anyshader)
	        cmds.hyperShade(assign = shader)
	    except:
	        pass
	    
	    
	
	return shader

'''
########################################  OTHER FUNCTIONS  ############################################
'''

def PluginsLister():
	
	pluginList = cmds.pluginInfo(q=1, ls=1)
	destinationList = []

	if 'vrayformaya' in pluginList:
		destinationList.append(['VRayMtl' , 'VRayMtl'])
	if 'mtoa' in pluginList:
		destinationList.append(['AiStandard' , 'aiStandard'])
	if 'OctanePlugin' in pluginList:
		destinationList.append(['Octane Diffuse material' , 'octaneDiffuseMaterial'])
		destinationList.append(['Octane Glossy material' , 'octaneGlossyMaterial'])
		destinationList.append(['Octane Specular material' , 'octaneSpecularMaterial'])
	if 'Mayatomr' in pluginList:
		#destinationList.append(['Mia_material' , 'mia_material'])
		destinationList.append(['Mia_material_x' , 'mia_material_x'])
		destinationList.append(['Mia_material_x_passes' , 'mia_material_x_passes'])

	destinationList.append(['Maya Lambert' , 'lambert'])
	destinationList.append(['Maya Blinn' , 'blinn'])
	destinationList.append(['Maya Phong' , 'phong'])
	destinationList.append(['Maya Phong E' , 'phongE'])
	

	return destinationList

	
def PluginsShaders():
	
	for i in destinationList:
		cmds.menuItem(l=i[0])





def ShaderConversion():
	new_shaders = []
	failed_shaders = []
	if (cmds.ls(sl=1)) == []:
		cmds.confirmDialog(title = "Warning", m = "Please select the shaders to be converted in the Hypershade", b="OK")
	
	
	diff_map=diff_node=diff_node_full=diff_text=diff_RGB=diff_weight=refl_map=refl_node=refl_text=refl_RGB=refl_weight=refl_gloss=bump_map=bump_2d_node=bump_node=bump_text=bump_weight=opacity_map=opacity_weight=opacity_text=opacity_node=opacity_node_full=-1
	shadersList = cmds.ls(sl=1)

	destinationShader = cmds.optionMenu("ShadersMenu", q=1, v=1)
	
	
	
	
	for anyshader in shadersList:
		

		i = cmds.ls(anyshader,showType=1)
		shaderType = i[1]
		i = i[0]
		
		print ('Processing shader %s'%i)
				
		if shaderType == 'blinn' or shaderType == 'lambert' or shaderType == 'phong' or shaderType == 'phongE':
			j = ShaderStandard()

		if shaderType == 'mia_material' or shaderType == 'mia_material_x' or shaderType == 'mia_material_x_passes':
			j = ShaderMR()

		if shaderType == 'VRayMtl':
			j = ShaderVray()

		if shaderType == 'aiStandard':
			j = ShaderAI()

		if shaderType == 'octaneDiffuseMaterial' or shaderType == 'octaneGlossyMaterial' or shaderType == 'octaneSpecularMaterial':
			j = ShaderOct()


		try:
			i,j,shaderType,diff_map,diff_node,diff_node_full,diff_text,diff_RGB,diff_weight,refl_map,refl_node,refl_text,refl_RGB,refl_weight,refl_gloss,bump_map,bump_2d_node,bump_node,bump_text,bump_weight,opacity_map,opacity_weight,opacity_text,opacity_node,opacity_node_full = GetShader(i,j,shaderType,diff_map,diff_node,diff_node_full,diff_text,diff_RGB,diff_weight,refl_map,refl_node,refl_text,refl_RGB,refl_weight,refl_gloss,bump_map,bump_2d_node,bump_node,bump_text,bump_weight,opacity_map,opacity_weight,opacity_text,opacity_node,opacity_node_full)
			
			shader = SetShader(anyshader,i,j,destinationShader,diff_map,diff_node,diff_node_full,diff_text,diff_RGB,diff_weight,refl_map,refl_node,refl_text,refl_RGB,refl_weight,refl_gloss,bump_map,bump_2d_node,bump_node,bump_text,bump_weight,opacity_map,opacity_weight,opacity_text,opacity_node,opacity_node_full)
			new_shaders.append(shader)
		except:
			failed_shaders.append(i)
		
	if failed_shaders == []:
		cmds.confirmDialog(t="Convert Shaders Message", m="Success!  All shaders were converted.", b='OK')
	else:
		cmds.confirmDialog(t="Convert Shaders Message", m="Warning: Some shaders were not processed.  Please convert manually %s"%failed_shaders,b='OK')

	cmds.select(new_shaders)

def ConvertShader_UI():
	
	if cmds.window('Convert_Shader_UI', exists=1):
		cmds.deleteUI('Convert_Shader_UI')
		
			
	
	ConvertShader_window = cmds.window('Convert_Shader_UI', bgc=[0.2,0.2,0.2], mnb=0, mxb=0, title="Convert Shaders %s"%ver_number, sizeable=0)
	
	MainLayout = cmds.rowColumnLayout(w=400, nc=1)
	
	
	cmds.image(image='%s\EMG_Convert_Shaders_UI.png'%(cmds.internalVar(ubd=1)))
	cmds.separator(h=20,w=400,style='none')
	
	cmds.text(l="Select the shaders to be converted in the Hypershade")
	cmds.separator(h=20,style='none')
	cmds.text(l="Choose your destination shader type")
	cmds.separator(h=20,style='none')
	list_name = cmds.optionMenu("ShadersMenu", w= 400, h=45, bgc=[0.27,0.27,0.27])
	PluginsShaders()
	cmds.separator(h=40,style='none')
	
	cmds.checkBox("Apply_chk", l='Auto-apply new shaders', v=1)
	
	cmds.text(l="Prefix /  Suffix (optional)")
	prefix = cmds.textField("Prefix_name",h=25)
	suffix = cmds.textField("Suffix_name",h=25)
	cmds.separator(h=40,style='none')
	
	OK = cmds.button("OK", l='OK', w=25, h=40, c='ShaderConversion()')
	Cancel = cmds.button("Cancel", l='Cancel', h=40, c='delUI()')
	
	

	cmds.showWindow('Convert_Shader_UI')



def delUI():
	cmds.deleteUI('Convert_Shader_UI')




destinationList = PluginsLister()

ConvertShader_UI()

